@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Channel.tcl,v $
-# $Date: 1998/12/03 17:06:54 $
-# $Revision: 1.18.1.182 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Channel.tcl,v $
+# $Date: 1999/05/17 09:18:22 $
+# $Revision: 1.18.1.187 $
 #
 #
 package provide zircon 1.18
@@ -172,11 +172,11 @@ proc channel_show {this args} {
 	$wndw register $this "$this doLeave {}" $del
   	$wndw setIcon $this $wname
   	makeCBody $this $w $rchan $chan $net $args $look
-	switch {} [$this logfile] {} default {
-	    switch {} [$this logfd] {
-	    	logOpen $this a 0 [$this logfile]
-	    }
-	}
+#	switch {} [$this logfile] {} default {
+#	    switch {} [$this logfd] {
+#	    	logOpen $this a 0 [$this logfile]
+#	    }
+#	}
 	switch {} $xc {} default { eval $xc }
 	$this defaultTags
 	$this configure -dwin [WBoard -channel $this]
@@ -237,6 +237,7 @@ proc channel_addText {this tag text} {
 }
 #
 proc channel_send {this string args} {
+    global user host
     switch {} $string {} default {
 	global Secure
 	$this addHist $string
@@ -247,7 +248,8 @@ proc channel_send {this string args} {
 	switch {} [set key [$this crypt]] {
 	    $net q1Send "PRIVMSG $rchan :$string"
 	} default {
-	    $net q1Send "PRIVMSG $rchan :[encrypt $string $key]"
+	    set gsh $string
+	    $net q1Send "PRIVMSG $rchan :[encrypt $gsh $key]"
 	}
 	regsub -all %n [$this mytag] [[$net myid] name] pr
 	switch -- $args {} {
@@ -255,6 +257,9 @@ proc channel_send {this string args} {
 	} default {
 	    $this doAddText @me "$pr $string"
 	}
+	if {[$this selfpattern]} {
+	    doPatterns $this [[$net myid] name]!$user@$host $string
+	}
     }
 }
 #
@@ -1650,7 +1655,7 @@ proc channel_mode {this vals prefix} {
 			switch + $flag {append nxt $flag$m} default {
 			    set cdata(limit) {}
 			    $this showInfo limit {}
-			    handleOn $net MODE [list [$this name] -$m]
+			    handleOn $net MODE [list [$this name] -$m {} $prefix]
 			}
 		    }
 		b - k - o - v { append nxt $flag$m }
@@ -1668,7 +1673,7 @@ proc channel_mode {this vals prefix} {
 			    $net q1Send "NAMES :[$this name]"
 			}
 			# set cdata(lcla) $cdata(a)
-			handleOn $net MODE [list [$this name] ${flag}a]
+			handleOn $net MODE [list [$this name] ${flag}a {} $prefix]
 		    }
 		m {
 			if {[set cdata(m) [string match + $flag]]} {
@@ -1679,12 +1684,12 @@ proc channel_mode {this vals prefix} {
 			# set cdata(lclm) $cdata(m)
 			$this cmdState
 			$this showFlags mod $mt
-			handleOn $net MODE [list [$this name] ${flag}m]
+			handleOn $net MODE [list [$this name] ${flag}m {} $prefix]
 		    }
 		p - s - i - n {
 			set cdata($m) [string match + $flag]
 			# set cdata(lcl$m) $cdata($m)
-			handleOn $net MODE [list [$this name] $flag$m]
+			handleOn $net MODE [list [$this name] $flag$m {} $prefix]
 		    }
 		t   {
 			set x [string match + $flag]
@@ -1696,7 +1701,7 @@ proc channel_mode {this vals prefix} {
 				$this topicState $st
 			    }
 			}
-			handleOn $net MODE [list [$this name] ${flag}t]
+			handleOn $net MODE [list [$this name] ${flag}t {} $prefix]
 		    }
 		}
 	    }
@@ -1726,7 +1731,7 @@ proc channel_mode {this vals prefix} {
 		}
 	    }
 	    set nxt [string range $nxt 2 end]
-	    handleOn $net MODE [list [$this name] $flag$m $par]
+	    handleOn $net MODE [list [$this name] $flag$m $par $prefix]
 	}
     }
     if {$cdata(modewait)} {
@@ -2019,3 +2024,10 @@ for channel [$this name] - \"$time\""
     set cdata(joinat) $time
     return 1
 }
+#
+proc channel_doNickAction {this usr action} {
+    regsub -all %n $action [$usr name] action
+    regsub -all %c $action [$this name] action
+    regsub -all %m $action [[[$this net] myid] name] action
+    $this action $action
+}
