@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Classes.tcl,v $
-# $Date: 1998/11/13 12:21:40 $
-# $Revision: 1.18.1.94 $
+# $Date: 1999/05/17 09:18:25 $
+# $Revision: 1.18.1.98 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -15,6 +15,7 @@ proc InitClasses {} {
     dispAd {Initialising classes...}
 #
 class Channel {
+    selfpattern	0	{bool {My msg check for -patterns}}
     timestamp	0	{bool {Display Timestamps}}
     noshare	0	{bool {Do Not Share}}
     nomerge	0	{bool {Do Not Merge}}
@@ -60,6 +61,7 @@ class Channel {
     mytag	{>}	{prompt {}}
     logtag	{>}	{prompt {}}
     iconify	{iconify} {operator {}}
+    nickactions	{}	{}
 } {
     name	{}
     lname	{}
@@ -203,6 +205,7 @@ class Friend {
     id		{}	{userhost}
     protect	{}	{list}
     image	{}	{filename}
+    actions	{}	{patterns}
 } {
     nick	{}
     lnick	{}
@@ -219,7 +222,7 @@ class Net "
     beep	BEEP	{text}
     busymsg	{I am busy and am not accepting calls at the moment.} {text}
     players	{}	{list}
-    setcolour	red	{colour}
+    setcolour	red	{}
     foreground	$zircon(fg)	{colour}
     myaddr	{}	{host}
     myport	{}	{portnumber}
@@ -287,7 +290,10 @@ class Net "
     nicksize	9	{int {Max. Nickname Size}}
     dccblock	2048	{int {DCC Blocksize}}
     msgmax	0	{int {Max. No. of Messages}}
+    nickactions	{}	{patterns}
+    urlcolour	{blue}	{colour}
 " {
+    memos	{}
     globfriend	{}
     whohandler	{}
     uhhandler	{}
