@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Control.tcl,v $
-# $Date: 1998/08/24 08:44:30 $
-# $Revision: 1.18.1.102 $
+# $Date: 1998/10/13 10:59:21 $
+# $Revision: 1.18.1.103 $
 #
 #
 package provide zircon 1.18
@@ -193,7 +193,7 @@ proc Control {args} {
     button $ctl.ii -command "ntoggleII $net $ctl.ii" -image $im
     set en [$this NNSBuild $ctl IRCName ircname [$net ircnames] $net $ctl.ii]
     bind $en <ButtonPress-3> "
-	popPalette .@pp$net {} $en [$defChan($net) colour] %X %Y
+	popPalette .@pp$net {} $en [list [$defChan($net) colour]] %X %Y
     "
     bind $en <Escape> "
     "
