@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/confInfo.tcl,v $
-# $Date: 1998/04/23 08:59:18 $
-# $Revision: 1.18.1.10 $
+# $Date: 1998/05/22 12:53:20 $
+# $Revision: 1.18.1.11 $
 #
 package provide zircon 1.18
 #
@@ -38,7 +38,7 @@ proc confInfo {net win} {
     }
     frame $win.list -relief raised
     evenGrid $win.list row 0 1
-    label $win.list.label1 -text "Send to Info :"
+    label $win.list.label1 -text "[trans {send to info}] :"
     grid $win.list.label1
     set i 0
     foreach ci [lindex [set Configure.Net(toInfo)] 1] {
@@ -48,7 +48,7 @@ proc confInfo {net win} {
 	set confI${net}(toInfo,$i) [expr {[lsearch [$net toInfo] $uci] >= 0}]
 	grid $win.list.inf${i} -row 0 -column [incr i] -sticky ew
     }
-    label $win.list.label2 -text "No Confirm :"
+    label $win.list.label2 -text "[trans {no confirm}] :"
     grid $win.list.label2
     set i 0
     foreach ci [lindex [set Configure.Net(noConfirm)] 1] {
@@ -62,28 +62,28 @@ proc confInfo {net win} {
     frame $win.filter -relief raised
     evenGrid $win.filter column 0 5
     checkbutton $win.filter.public -variable new${net}(showPublic) \
-      -text "Public" -command "confDirty $net"
+      -text [trans public] -command "confDirty $net"
 
     checkbutton $win.filter.local -variable new${net}(showLocal) \
-      -text "Local" -command "confDirty $net"
+      -text [trans local] -command "confDirty $net"
     checkbutton $win.filter.private -variable new${net}(showPrivate) \
-      -text "Private" -command "confDirty $net"
+      -text [trans private] -command "confDirty $net"
     checkbutton $win.filter.topic -variable new${net}(topicOnly) \
-      -text "With Topic" -command "confDirty $net"
+      -text [trans {with topic}] -command "confDirty $net"
     checkbutton $win.filter.sorted -variable new${net}(sorted) \
-      -text Sorted -command "confDirty $net"
+      -text [trans sorted] -command "confDirty $net"
     checkbutton $win.filter.noc -variable new${net}(nocase) \
-      -text "Ignore Case" -command "confDirty $net"
+      -text [trans nocase] -command "confDirty $net"
 
     scale $win.filter.members1 \
-      -from 1 -to 25 -label {Minimum Number of Members} \
+      -from 1 -to 25 -label [trans {minimum number of members}] \
       -showvalue 1 -orient horizontal
     $win.filter.members1 set [$net minMembers]
     $win.filter.members1 configure \
       -command "$win.filter.members1 configure \
 	-command {confDirty $net ; set new${net}(minMembers)} ; set x "
     scale $win.filter.members2 \
-      -from 0 -to 25 -label {Maximum Number of Members} \
+      -from 0 -to 25 -label [trans {maximum number of members}] \
       -showvalue 1 -orient horizontal
     $win.filter.members2 set [$net maxMembers]
     $win.filter.members2 configure \
@@ -93,9 +93,9 @@ proc confInfo {net win} {
     grid $win.filter.public $win.filter.local $win.filter.private \
       $win.filter.topic $win.filter.sorted $win.filter.noc
     frame $win.filter2
-    labelEntry 0 $win.filter2.c {-text {Channel Pattern} -width 16} \
+    labelEntry 0 $win.filter2.c "-text [list [trans {channel pattern}]] -width 16" \
       $newd(listPattern) "set new${net}(listPattern) \[%W get\] ; confDirty $net"
-    labelEntry 0 $win.filter2.t {-text {Topic Pattern} -width 16} \
+    labelEntry 0 $win.filter2.t "-text [list [trans {topic pattern}]] -width 16" \
       $newd(topicPattern) "set new${net}(topicPattern) \[%W get\] ; confDirty $net"
     grid $win.filter2.c $win.filter2.t -sticky ew
     evenGrid $win.filter2 column 0 1
