@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/confTab.tcl,v $
-# $Date: 1998/11/23 10:32:36 $
-# $Revision: 1.18.1.19 $
+# $Date: 1998/12/07 13:14:47 $
+# $Revision: 1.18.1.20 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -201,12 +201,11 @@ proc confDABtns {net args} {
 #
 proc confRABtns {net args} {
     global cbwstate tablock
-    set win .@conf$net
     foreach bt {revert apply save dismiss} {
 	switch {} [$net confChange] {set st $cbwstate($net,$bt) } default {
 	  set st normal
 	}
-	$win.btn.$bt configure -state $st
+	catch {$win.btn.$bt configure -state $st}
 	catch {unset cbwstate($net,$bt)}
     }
     catch {unset tablock($net)}
