@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/debug.tcl,v $
-# $Date: 1998/07/21 13:15:27 $
-# $Revision: 1.18.1.39 $
+# $Date: 1998/12/21 09:50:45 $
+# $Revision: 1.18.1.41 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -83,7 +83,7 @@ $errorInfo"
     set msg  "Zircon has detected an internal error \"$msg\" when processing\
       \"$cmd\" from \"$prefix\" ($param $rest). The stack trace has\
       been saved in file \"$file\". Please send this information to\
-      zircon@catless.ncl.ac.uk."
+      Lindsay.Marshall@newcastle.ac.uk."
       tellError $currentNet {Internal Error} $msg ZERROR
 }
 #
@@ -255,6 +255,7 @@ proc zDBGControl {} {
 	}
     }
     catch {wm geometry $ctl $zlayout(default,debug)}
+    set zscr(dbg) 1
 }
 #
 proc RDBG {} {
